state_persistence library
Classes
- JsonFileStorage
- Uses the default JsonCodec, to store the persisted state.
- PersistedAppState
- Add to your widget hierarchy to add app-wide state persistence.
- PersistedData
- Accessed as a map so you can store key/value pairs of data. Values are dynamic allowing you do store information in multiple depths. This however doesn't guarantee the storage mechanism will save/load multiple depths.
- PersistedStateBuilder
- You can use this builder to access the current persisted data. It will automatically rebuild when the persisted data is loaded.
- PersistedStateStorage
- Extend this class to provide your own persisted storage mechanism.